@@ -426,6 +426,11 @@ class CliArgs(object):
             action='store_true'
         )
 
+        standard.add_argument(
+            '--output-file', type=str, default=None,
+            help='Writes the output to the specified file, ideal for producing reports'
+        )
+
         return parser
 
 
@@ -655,3 +660,8 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs, object):
     def build_graph(self):
         """ build_graph """
         return self._get_argument_value('build_graph', False, False)
+
+    @property
+    def output_file(self):
+        """ output_file """
+        return self._get_argument_value('output_file', False, True)
