@@ -16,53 +16,51 @@ class Equals(CloudFormationLintRule):
     tags = ['functions', 'equals']
 
     def match(self, cfn):
-        """Check CloudFormation Equals"""
-
+        function = 'Fn::Equals'
         matches = []
-
         # Build the list of functions
-        equal_trees = cfn.search_deep_keys('Fn::Equals')
+        trees = cfn.search_deep_keys(function)
 
         allowed_functions = ['Ref', 'Fn::FindInMap',
                              'Fn::Sub', 'Fn::Join', 'Fn::Select', 'Fn::Split']
 
-        for equal_tree in equal_trees:
+        for tree in trees:
             # Test when in Conditions
-            if equal_tree[0] == 'Conditions':
-                equal = equal_tree[-1]
-                if not isinstance(equal, list):
-                    message = 'Fn::Equals must be a list of two elements'
+            if tree[0] == 'Conditions':
+                value = tree[-1]
+                if not isinstance(value, list):
+                    message = function + ' must be a list of two elements'
                     matches.append(RuleMatch(
-                        equal_tree[:-1],
+                        tree[:-1],
                         message.format()
                     ))
-                elif len(equal) != 2:
-                    message = 'Fn::Equals must be a list of two elements'
+                elif len(value) != 2:
+                    message = function + ' must be a list of two elements'
                     matches.append(RuleMatch(
-                        equal_tree[:-1],
+                        tree[:-1],
                         message.format()
                     ))
                 else:
-                    for index, element in enumerate(equal):
+                    for index, element in enumerate(value):
                         if isinstance(element, dict):
                             if len(element) == 1:
                                 for element_key in element.keys():
                                     if element_key not in allowed_functions:
-                                        message = 'Fn::Equals element must be a supported function ({0})'
+                                        message = function + ' element must be a supported function ({0})'
                                         matches.append(RuleMatch(
-                                            equal_tree[:-1] + [index, element_key],
+                                            tree[:-1] + [index, element_key],
                                             message.format(', '.join(allowed_functions))
                                         ))
                             else:
-                                message = 'Fn::Equals element must be a supported function ({0})'
+                                message = function + ' element must be a supported function ({0})'
                                 matches.append(RuleMatch(
-                                    equal_tree[:-1] + [index],
+                                    tree[:-1] + [index],
                                     message.format(', '.join(allowed_functions))
                                 ))
                         elif not isinstance(element, (six.string_types, bool, six.integer_types, float)):
-                            message = 'Fn::Equals element must be a String, Boolean, Number, or supported function ({0})'
+                            message = function + ' element must be a String, Boolean, Number, or supported function ({0})'
                             matches.append(RuleMatch(
-                                equal_tree[:-1] + [index],
+                                tree[:-1] + [index],
                                 message.format(', '.join(allowed_functions))
                             ))
 
